@@ -96,10 +96,15 @@ class FeedForwardWithCompressionState(nn.Module):
             self.net4 = nn.Dropout(dropout)
         else:
             self.net4 = nn.Identity()
+        # .state: torch.Size([]), x: torch.Size([128, 256, 256]), self.state_gate: torch.Size([1024, 1024]), self.state_zero: torch.Size([1024, 1024])
+        self.state_gate = torch.randn(hidden_size, hidden_size, device=device) / 10.0
+        self.state_zero = torch.zeros((hidden_size, hidden_size), device=device)
 
     def forward(self, x, state):
-        # print(f"state: {state.shape}, x: {x.shape}")
-        x = self.net1(x) + state
+        print(
+            f"state: {state.shape}, x: {x.shape}, self.state_gate: {self.state_gate.shape}, self.state_zero: {self.state_zero.shape}"
+        )
+        x = (self.net1(x).T + self.state_gate @ (self.state_zero + state)).T
         x = self.net2(x)
         state = x
         x = self.net3(x)
